/******************************************************************/
/* E-DigTime v0.1                                                 */
/*   author: Shawn M. Veader                                      */
/*   email: veader@cc.gatech.edu                                  */
/*   update: 11.15.99 - code clean up. check for consistency with */
/*                      current libepplet. also increased timer   */
/*                      length so it won't update so much         */
/******************************************************************/
#include <stdio.h>
#include <sys/time.h>
#include <sys/resource.h>
/*#include <signal.h>
#include <sys/wait.h>
#include <errno.h>
#include <time.h>*/
#include <epplet.h>

#define STRMAX 256

Epplet_gadget button_close, button_help, txt_time, txt_date;
int noDate;

/* forward declarations */
static void cb_timer(void *data);
static void cb_close(void *data);
static void cb_help(void *data);
static void cb_in(void *data, Window w);
static void cb_out(void *data, Window w);

/* the timer callback. this does the work of figuring the time
 * and displaying it on the epplet */
static void
cb_timer(void *data)
{
	char      s[STRMAX];
	time_t    temptime;
	struct tm *cur_time;

	temptime = time(NULL);
	cur_time = localtime(&temptime);
	strftime(s, STRMAX, "%I:%M:%S %p", cur_time);
	Epplet_change_label(txt_time, s);
	if(noDate == 0) {
		strftime(s, STRMAX, "%a %b %d %Y", cur_time);
		Epplet_change_label(txt_date, s);
	}

	data = NULL;
	Epplet_timer(cb_timer, NULL, 0.5, "TIMER");
}
/* called when you close the epplet */
static void
cb_close(void *data)
{
	Epplet_unremember();
	Esync();
	data = NULL;
	exit(0);
}
/* called when the '?' button is pressed */
static void
cb_help(void *data)
{
	data = NULL;
	Epplet_show_about("E-DigTime");
}
/* called when the epplet gets focus */
static void
cb_in(void *data, Window w)
{
	Epplet_gadget_show(button_close);
	Epplet_gadget_show(button_help);
	return;
	data = NULL;
	w = (Window) 0;
}
/* called when the epplet loses the focus */
static void
cb_out(void *data, Window w)
{
	Epplet_gadget_hide(button_close);
	Epplet_gadget_hide(button_help);
	return;
	data = NULL;
	w = (Window) 0;
}
/* where it all begins... */
int
main(int argc, char *argv[])
{
	int prio;
	char s[64];

	/* bump up our priority so we don't burn up the cpu's time */
	prio = getpriority(PRIO_PROCESS, getpid());
	setpriority(PRIO_PROCESS, getpid(), prio + 10);
	atexit(Epplet_cleanup);

	/* default has the date displayed */
	noDate = 0;
	
	/* if we have cmd line args, check them for valid ones */
	if(argc >= 2) {
		if(strcmp(argv[1], "--nodate") == 0) {
			noDate = 1;
		}
	}

	if(noDate == 0) {
		Epplet_Init("E-DigTime", "0.2", "E Digital Time Epplet",
					6, 2, argc, argv, 0);
	} else {
		Epplet_Init("E-DigTime", "0.2", "E Digital Time Eppelt",
					6, 1, argc, argv, 0);
	}
	Epplet_load_config();
	Epplet_timer(cb_timer, NULL, 0.5, "TIMER");

	button_close = Epplet_create_button(NULL, NULL,
					  3, 2, 0, 0, "CLOSE", 0, NULL,
					  cb_close, NULL);
	button_help = Epplet_create_button(NULL, NULL,
					  81, 2, 0, 0, "HELP", 0, NULL,
					  cb_help, NULL);
	sprintf(s, "12:30:00 PM");
	if(noDate == 0) {
		Epplet_gadget_show(txt_time = Epplet_create_label(9, 5, s, 3));
	} else {
		Epplet_gadget_show(txt_time = Epplet_create_label(9, 1, s, 3));
	}
	if(noDate == 0) {
		sprintf(s, "Thu Nov 04 1999");
		Epplet_gadget_show(txt_date = Epplet_create_label(5, 18, s, 2));
	}
 
	Epplet_register_focus_in_handler(cb_in, NULL);
	Epplet_register_focus_out_handler(cb_out, NULL);
  
	Epplet_show();
	Epplet_Loop();
	return 0;
}

